@@ -1,5 +1,6 @@
 import io
 from typing import Union
+from zipfile import ZipFile
 
 import htmlgenerator as hg
 from django import forms
@@ -12,6 +13,7 @@ from django.utils.translation import get_language
 from django.utils.translation import gettext_lazy as _
 from docxtpl import DocxTemplate
 from jinja2.sandbox import SandboxedEnvironment
+from lxml import etree
 
 from basxbread import utils
 
@@ -39,7 +41,7 @@ class DocumentTemplate(models.Model):
     def context(self, object):
         context = {}
         for variable in self.variables.all():
-            context[variable.name] = hg.resolve_lookup(object, variable.value)
+            context[variable.name] = hg.resolve_lookup(object, variable.value) or ""
             if variable.template:
                 try:
                     context[variable.name] = utils.jinja_render(
@@ -76,13 +78,29 @@ class DocumentTemplate(models.Model):
         both = intemplate | declared
         return declared ^ both, intemplate ^ both
 
-    def generate_document_url(self, obj: Union[hg.Lazy, models.Model]):
+    def all_used_fonts(self):
+        with ZipFile(self.file, "r") as myzip:
+            with myzip.open("word/fontTable.xml") as f:
+                fontsxml = etree.parse(f)
+        fonts = set()
+        for i in fontsxml.findall("{*}font"):
+            for key, value in i.attrib.items():
+                if key.endswith("name"):
+                    fonts.add(value)
+        return [f for f in fonts if f is not None]
+
+    def generate_document_url(self, obj: Union[hg.Lazy, models.Model], pdf=False):
         return utils.ModelHref.from_object(
             self,
-            "generate_document",
+            "generate_document_pdf" if pdf else "generate_document",
             kwargs={"object_pk": obj.pk},
         )
 
+    def save(self, *args, **kwargs):
+        super().save(*args, **kwargs)
+        for missing in self.missing_variables()[0]:
+            self.variables.create(name=missing)
+
     def __str__(self):
         return self.name
 
@@ -99,7 +117,10 @@ class DocumentTemplateVariable(models.Model):
         _("Name"), max_length=255, help_text=_("Name to use in the template document")
     )
     value = models.CharField(
-        _("Value"), max_length=255, help_text=_("Path to the desired value (see help)")
+        _("Value"),
+        max_length=255,
+        help_text=_("Path to the desired value (see help)"),
+        blank=True,
     )
     template = models.TextField(
         _("Template"),
