@@ -1,9 +1,15 @@
+import os
+import shutil
+import subprocess  # nosec
+import tempfile
+
 import htmlgenerator as hg
 from django.http import HttpResponse
 from django.utils.translation import gettext_lazy as _
 
 from basxbread import layout, utils, views
 
+from .fontfinder import systemfonts
 from .models import DocumentTemplate
 
 
@@ -32,6 +38,17 @@ class DocumentTemplateEditView(views.EditView):
                     kind="error",
                 )
             )
+        allsystemfonts = set(systemfonts())
+        documentfonts = set(self.object.all_used_fonts())
+        missingfonts = documentfonts.difference(allsystemfonts)
+        if missingfonts:
+            warnings.append(
+                layout.notification.InlineNotification(
+                    _("Missing system fonts, used in the docx template: "),
+                    f"{', '.join(missingfonts)}",
+                    kind="warning",
+                )
+            )
         if only_template:
             warnings.append(
                 layout.notification.InlineNotification(
@@ -95,7 +112,7 @@ class DocumentTemplateEditView(views.EditView):
         return self.request.get_full_path()
 
 
-def generate_document(request, pk: int, object_pk: int):
+def _generate_document(pk: int, object_pk: int):
     template = DocumentTemplate.objects.get(pk=pk)
     object = template.model.get_object_for_this_type(pk=object_pk)
     filename = f'{template.name}_{str(object).replace(" ", "-")}'
@@ -114,12 +131,46 @@ def generate_document(request, pk: int, object_pk: int):
             print(e)
             filename = "FILENAME_ERROR.docx"
 
+    return (
+        filename,
+        template.render_with(object),
+    )
+
+
+def generate_document(request, pk: int, object_pk: int):
+    filename, content = _generate_document(pk, object_pk)
     if not filename.endswith(".docx"):
         filename = filename + ".docx"
 
     response = HttpResponse(
-        template.render_with(object),
+        content,
         content_type="application/vnd.openxmlformats-officedocument.wordprocessingml.document",
     )
     response["Content-Disposition"] = f'attachment; filename="{filename}"'
     return response
+
+
+def generate_document_pdf(request, pk: int, object_pk: int):
+    filename, content = _generate_document(pk, object_pk)
+    if not filename.endswith(".pdf"):
+        filename = filename + ".pdf"
+    with tempfile.TemporaryDirectory() as tmpdir:
+        with tempfile.NamedTemporaryFile(mode="wb", suffix=".docx") as file:
+            file.write(content.read())
+            subprocess.run(
+                [
+                    shutil.which("libreoffice")
+                    or "false",  # statisfies mypy, since which may return None
+                    "--convert-to",
+                    "pdf",
+                    file.name,
+                    "--outdir",
+                    tmpdir,
+                ],
+                shell=False,
+            )  # nosec
+            outfilename = os.path.basename(file.name)[:-4] + "pdf"
+        with open(os.path.join(tmpdir, outfilename), "rb") as pdffile:
+            response = HttpResponse(pdffile, content_type="application/pdf")
+            response["Content-Disposition"] = f'attachment; filename="{filename}"'
+            return response
